# RUIN
## The foundation to build your python/mongo application on..

Provides basic capabilities for Mongo CRUD. Also provides models for defining and validation Mongo schema.

Provides managers to call db functions.

## TODO usage examples

MIT license
